@@ -61,10 +61,15 @@ def __fini():
 
 
 def start():
-    print("FAST: Config.Enable is %s " % config.enable)
+    logger.debug("FAST: Config.Enable is %s " % config.enable)
     # 如果探针开关关闭,则不执行探针的初始化操作，不启动探针
     if not config.enable:
         return False
+
+    if not config.product_code or not config.app_code:
+        logger.error("FAST: 缺少product_code或app_code字段值，探针初始化失败")
+        return False
+
     flag = False
     try:
         # 猴子补丁，运行时动态替换
@@ -80,7 +85,8 @@ def start():
         grpc_gevent.init_gevent()
     global __started
     if __started:
-        raise RuntimeError("此代理只能启动一次")
+        logger.error("FAST: 此代理只能启动一次")
+        return False
     # 初始化log模块
     loggings.init()
     # 配置需要忽略的文件夹
@@ -114,4 +120,5 @@ def archive(segment: "Segment"):
     try:  # unlike checking __queue.full() then inserting, this is atomic
         __queue.put(segment, block=False)
     except Full:
-        logger.warning("队列已满，该segment将被放弃!")
+        print("队列已满，该segment将被放弃!")
+        # logger.warning("队列已满，该segment将被放弃!")
