@@ -9,6 +9,9 @@ import os
 import re
 import uuid
 
+import fast_tracker
+from fast_tracker.loggings import logger
+
 RE_IGNORE_PATH = os.getenv("FastTracker_ReIgnorePath") or re.compile("^$")  # type: re.Pattern
 
 service_instance = os.getenv("FastTracker_Instance") or str(uuid.uuid1()).replace("-", "")  # type: str
@@ -21,12 +24,13 @@ correlation_value_max_length = int(os.getenv("FastTracker_CorrelationValueMaxLen
 trace_ignore_path = os.getenv("FastTracker_IgnorePath") or ""  # type: str
 
 ############################# fast_tracker默认配置信息开始 ###############################
+tracker_version = fast_tracker.version
 # agent全局开关，默认false
 enable = False  # type: bool
 # 环境编码
 env_code = "test"  # type: str
 # 日志等级
-log_level = "ERROR"  # type: str
+logging_level = "ERROR"  # type: str
 # 租户编码
 tenant_code = ""  # type: str
 # 用户编码
@@ -63,7 +67,7 @@ def init(
 ):
     # 先根据环境变量 FastTracker_ConfigPath 加载配置文件并赋值
     config_file = os.environ.get("FastTracker_ConfigPath", None)
-    print("FAST: FastTracker_ConfigPath is %s " % config_file)
+    logger.debug("FAST: FastTracker_ConfigPath is %s " % config_file)
     from fast_tracker.fast_tracker_configer import FastTrackerConfiger
 
     if config_file:
@@ -96,6 +100,16 @@ def set_enable(cus_enable: bool = False):
     enable = cus_enable
 
 
+def set_debug(cus_debug: bool = False):
+    """
+    设置 debug 值
+    :param cus_debug:
+    :return:
+    """
+    global debug
+    debug = cus_debug
+
+
 def set_env_code(cus_env_code: str = ""):
     """
     设置env_code值
@@ -312,6 +326,18 @@ def get_tracker_name():
     return carrier_header.get("TrackerName")
 
 
+def set_logging(**kwargs):
+    """
+    设置 logging_level
+    :param kwargs:
+    :return:
+    """
+    global logging_level
+    if not kwargs.get("Level"):
+        return False
+    logging_level = kwargs.get("Level")
+
+
 def finalize():
     """
     通过忽略后缀的文件找到忽略的文件夹
