@@ -204,9 +204,10 @@ class FastTracker:
     def get_config():
         return {
             "ServiceName": config.service_name,
+            "TrackerVersion": config.tracker_version,
             "ServiceInstance": config.service_instance,
             "Protocol": config.protocol,
-            "LogLevel": config.log_level,
+            "LogLevel": config.logging_level,
             "IgnoreSuffix": config.ignore_suffix,
             "CorrelationElementMaxNumber": config.correlation_element_max_number,
             "CorrelationValueMaxLength": config.correlation_value_max_length,
@@ -252,7 +253,7 @@ class FastTracker:
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         try:
-            self.span.tag(Tag(key=key, val=val))
+            self.span.tag(Tag(key=key, val=val, overridable=True))
         except Exception as e:
             raise e
 
