@@ -17,6 +17,8 @@ class FastTrackerConfiger:
     def _default_config_keys():
         return [
             "Enable",
+            "Debug",
+            "Logging",
             "EnvCode",
             "TenantCode",
             "UserCode",
@@ -37,7 +39,6 @@ class FastTrackerConfiger:
     def load_configuration(config_file=None):
         """
         :param config_file: 配置文件地址
-        :param log_level:
         :return:
         """
         if not config_file:
@@ -63,6 +64,8 @@ class FastTrackerConfiger:
                                 config.set_env_code_reader(**config_dict.get(config_key))
                             elif config_key == "CarrierHeader":
                                 config.set_carrier_header(**config_dict.get(config_key))
+                            elif config_key == "Logging":
+                                config.set_logging(**config_dict.get(config_key))
                             else:
                                 getattr(config, func_name)(config_dict.get(config_key))
 
@@ -90,6 +93,10 @@ class FastTrackerConfiger:
                 elif key.startswith("FastTracker_CarrierHeader_"):
                     args = {functions.lower_case_name(key[26:]): val}
                     config.set_carrier_header(**args)
+                elif key == "FastTracker_SocketPath":
+                    setattr(config, "collector_address", val)
+                elif key == "FastTracker_Logging_Level":
+                    setattr(config, "logging_level", val)
                 else:
                     config_name = functions.lower_case_name(key[12:])
                     setattr(config, config_name, val)
